@@ -118,7 +118,7 @@ log = logging.getLogger(__name__)
 
 agent_log = None
 
-VERSION = '0.8.0'
+VERSION = '0.8.1'
 DEFAULT_ENDPOINT = 'https://api.rollbar.com/api/1/'
 DEFAULT_TIMEOUT = 3
 
@@ -606,6 +606,14 @@ def _add_locals_data(data, exc_info):
         tb_frame = cur_tb.tb_frame
         cur_tb = cur_tb.tb_next
 
+        if not isinstance(tb_frame, types.FrameType):
+            # this can happen if the traceback or frame is wrapped in some way,
+            # for example by `ExceptionInfo` in
+            # https://github.com/celery/billiard/blob/master/billiard/einfo.py
+            log.warning('Traceback frame not a types.FrameType. Ignoring.')
+            frame_num += 1
+            continue
+
         # Create placeholders for args/kwargs/locals
         args = []
         kw = {}
@@ -881,7 +889,7 @@ def _build_werkzeug_request_data(request):
     }
 
     if request.get_json():
-        request_data['body'] = json.dumps(_scrub_request_params(request.json))
+        request_data['body'] = json.dumps(_scrub_obj(request.json))
 
     return request_data
 
